@@ -2,9 +2,9 @@ use 5.008;
 use strict;
 use warnings;
 
-package Perl::PrereqScanner;
+package Perl::PrereqScanner 1.024;
 # ABSTRACT: a tool to scan your Perl code for its prerequisites
-$Perl::PrereqScanner::VERSION = '1.022';
+
 use Moose;
 
 use List::Util qw(max);
@@ -150,7 +150,7 @@ Perl::PrereqScanner - a tool to scan your Perl code for its prerequisites
 
 =head1 VERSION
 
-version 1.022
+version 1.024
 
 =head1 SYNOPSIS
 
@@ -206,6 +206,16 @@ constructing your PrereqScanner:
   # Use any stock scanners, plus Example:
   my $scanner = Perl::PrereqScanner->new({ extra_scanners => [ qw(Example) ] });
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 scan_string
@@ -261,7 +271,79 @@ Jerome Quelin
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=for stopwords bowtie celogeek Christopher J. Madsen David Golden Steinbrunner Ed J Florian Ragwitz Jakob Voss Jérôme Quelin John SJ Anderson Karen Etheridge Mark Gardner Neil Bowers Randy Stauner Tina Mueller Vyacheslav Matjukhin
+
+=over 4
+
+=item *
+
+bowtie <bowtie@cpan.org>
+
+=item *
+
+celogeek <me@celogeek.com>
+
+=item *
+
+Christopher J. Madsen <perl@cjmweb.net>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+David Steinbrunner <dsteinbrunner@pobox.com>
+
+=item *
+
+Ed J <mohawk2@users.noreply.github.com>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Jakob Voss <voss@gbv.de>
+
+=item *
+
+Jérôme Quelin <jquelin@gmail.com>
+
+=item *
+
+John SJ Anderson <genehack@genehack.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Mark Gardner <gardnerm@gsicommerce.com>
+
+=item *
+
+Neil Bowers <neil@bowers.com>
+
+=item *
+
+Randy Stauner <rwstauner@cpan.org>
+
+=item *
+
+Tina Mueller <tinita@cpan.org>
+
+=item *
+
+Vyacheslav Matjukhin <mmcleric@yandex-team.ru>
 
 =back
 
